/** @jsxRuntime classic */
/** @jsx jsx */
import { jsx } from '@keystone-ui/core';
import { MutableRefObject, ReactNode } from 'react';
import { Element, Descendant } from 'slate';
import { ReactEditor } from 'slate-react';
import { ComponentBlock } from '../component-blocks';
import { DocumentFeatures } from '../views';
import { Relationships } from './relationship';
export { Editor } from 'slate';
export declare function createDocumentEditor(documentFeatures: DocumentFeatures, componentBlocks: Record<string, ComponentBlock>, relationships: Relationships, isShiftPressedRef: MutableRefObject<boolean>): import("slate").BaseEditor & {
    type?: undefined;
} & ReactEditor & import("slate-history").HistoryEditor;
export declare function DocumentEditor({ autoFocus, onChange, value, componentBlocks, relationships, documentFeatures, }: {
    autoFocus?: boolean;
    onChange: undefined | ((value: Descendant[]) => void);
    value: Descendant[];
    componentBlocks: Record<string, ComponentBlock>;
    relationships: Relationships;
    documentFeatures: DocumentFeatures;
}): jsx.JSX.Element;
export declare function DocumentEditorProvider({ children, editor, onChange, value, componentBlocks, documentFeatures, relationships, }: {
    children: ReactNode;
    value: Descendant[];
    onChange: (value: Descendant[]) => void;
    editor: ReactEditor;
    componentBlocks: Record<string, ComponentBlock>;
    relationships: Relationships;
    documentFeatures: DocumentFeatures;
}): jsx.JSX.Element;
export declare function DocumentEditorEditable({ autoFocus, readOnly, className, }: {
    autoFocus?: boolean;
    readOnly?: boolean;
    className?: string;
}): jsx.JSX.Element;
declare type Block = Exclude<Element, {
    type: 'relationship' | 'link';
}>;
declare type BlockType = Block['type'];
declare type EditorSchema = Record<BlockType | 'editor', {
    kind: 'blocks';
    allowedChildren: ReadonlySet<Element['type']>;
    blockToWrapInlinesIn: TypesWhichHaveNoExtraRequiredProps;
    invalidPositionHandleMode: 'unwrap' | 'move';
} | {
    kind: 'inlines';
    invalidPositionHandleMode: 'unwrap' | 'move';
}>;
declare type TypesWhichHaveNoExtraRequiredProps = {
    [Type in Block['type']]: {
        type: Type;
        children: Descendant[];
    } extends Block & {
        type: Type;
    } ? Type : never;
}[Block['type']];
export declare const editorSchema: EditorSchema;
